aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/bash/function/ansible.sh
diff options
context:
space:
mode:
authorPeter Mikus <pmikus@cisco.com>2020-01-24 14:56:57 +0000
committerPeter Mikus <pmikus@cisco.com>2020-02-04 15:22:38 +0000
commit2cf0755933dac3e95c10928347996bad3cbe0a42 (patch)
tree89a79eb7b4a27e47b60b4ac1e6bb6eb56903b781 /resources/libraries/bash/function/ansible.sh
parent35024b691ade4278f49d8a65d237c7112fa32bc2 (diff)
Ansible: Cleanup and speedup
Signed-off-by: Peter Mikus <pmikus@cisco.com> Change-Id: Ia2ce482798204ad426f93f334c97e28eb51139fd
Diffstat (limited to 'resources/libraries/bash/function/ansible.sh')
-rw-r--r--resources/libraries/bash/function/ansible.sh38
1 files changed, 31 insertions, 7 deletions
diff --git a/resources/libraries/bash/function/ansible.sh b/resources/libraries/bash/function/ansible.sh
index 431acc7c5d..56665dfa1c 100644
--- a/resources/libraries/bash/function/ansible.sh
+++ b/resources/libraries/bash/function/ansible.sh
@@ -1,6 +1,6 @@
#!/usr/bin/env bash
-# Copyright (c) 2019 Cisco and/or its affiliates.
+# Copyright (c) 2020 Cisco and/or its affiliates.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:
@@ -16,10 +16,9 @@
set -exuo pipefail
-function ansible_hosts () {
+function ansible_adhoc () {
- # Run ansible playbook on hosts in working topology file. Ansible scope is
- # determined by tags passed as parameters to this function.
+ # Run ansible ad-hoc command module on hosts in working topology file.
#
# Variable read:
# - ${WORKING_TOPOLOGY} - Reserved working topology.
@@ -31,9 +30,33 @@ function ansible_hosts () {
die "Please install sshpass!"
fi
- if ! installed ansible-playbook; then
- # TODO: Consider moving to requirements.txt?
- pip install ansible==2.7.8 || die "Install ansible via PIP failed!"
+ hosts=($(fgrep host "${WORKING_TOPOLOGY}" | cut -d ":" -f 2)) || {
+ die "Failed to read hosts from working topology!"
+ }
+ pushd "${TOOLS_DIR}"/testbed-setup/ansible || die "Pushd failed!"
+ ANSIBLE_STDOUT_CALLBACK=yaml ansible \
+ --vault-password-file=vault_pass \
+ --extra-vars '@vault.yml' \
+ --inventory inventories/lf_inventory/hosts site.yaml \
+ --limit "$(echo ${hosts[@]//\"})" \
+ --module-name shell \
+ --args \"$(echo $@)\" || die "Failed to run ansible on host!"
+ popd || die "Popd failed!"
+}
+
+function ansible_playbook () {
+
+ # Run ansible playbook on hosts in working topology file. Ansible scope is
+ # determined by tags passed as parameters to this function.
+ #
+ # Variable read:
+ # - ${WORKING_TOPOLOGY} - Reserved working topology.
+ # - ${TOOLS_DIR} - CSIT tools directory, where testbed-setup is located.
+
+ set -exuo pipefail
+
+ if ! installed sshpass; then
+ die "Please install sshpass!"
fi
hosts=($(fgrep host "${WORKING_TOPOLOGY}" | cut -d ":" -f 2)) || {
@@ -49,6 +72,7 @@ function ansible_hosts () {
popd || die "Popd failed!"
}
+
function installed () {
# Check if the given utility is installed. Fail if not installed.